@@ -84,11 +84,6 @@ class MenuBar(QMenuBar):
         self._menu_file.addAction(self._action_open_folder)
         self._menu_file.addSeparator()
         self._menu_file.addAction(self._action_close_all_folders)
-        if u'JupyterNotebook' in ide.extension_manager:
-            jupyter_notebook = ide.extension_manager['JupyterNotebook']
-            self._menu_file.addSeparator()
-            self._menu_file.addAction(jupyter_notebook.action_import_ipynb)
-            self._menu_file.addAction(jupyter_notebook.action_export_ipynb)
         self._menu_file.addSeparator()
         self._menu_file.addAction(self._action_quit)
         # Tools menu
